==> pEyOn___2022-12-16_05-12-22.zip: js/main.js <==
$(document).ready(function () {
  $('.js-btn').click(function(){
    if(!$(this).hasClass('active')){
      $(this).parents('ul').find('.js-btn').removeClass('active');
      $(this).addClass('active');
    }
  });
  
  $('.accordion-item a.btn-pause').click(function(){
    $(this).parents('.accordion-item').find('.form-check-input').removeClass('bg-success').addClass('bg-primary');
    $(this).find('i.mdi-pause-circle-outline').removeClass('mdi-pause-circle-outline text-secondary').addClass('mdi-pause-circle text-primary opacity-100');
  });

  $('.accordion-item .form-switch .form-check-input').change(function () {
    if (this.checked) {
      $(this).removeClass('bg-danger').addClass('bg-success');
      $(this).parents('.accordion-item').find('.btn-pause').removeClass('d-none');
      $(this).parents('.accordion-item').find('.last-use').addClass('d-none');
      $(this).parents('.accordion-item').find('.timer').removeClass('d-none');
    }else{
      $(this).removeClass('bg-success').addClass('bg-danger');
      $(this).parents('.accordion-item').find('.last-use').removeClass('d-none');
      $(this).parents('.accordion-item').find('.timer').addClass('d-none');
      $(this).parents('.accordion-item').find('.btn-pause').addClass('d-none');
      $(this).parents('.accordion-item').find('i').removeClass('mdi-pause-circle-outline mdi-pause-circle text-danger opacity-100').addClass('mdi-pause-circle-outline text-secondary');
    }
    if ($('.accordion-item .form-switch .form-check-input:checked').length > 1) {
      var myModal = new bootstrap.Modal(document.getElementById('conflictModal'));
      myModal.show();
    }
  });
});

// *************************************
// *********** POPUP *******************
// *************************************

function submitForm() {
  var obj = document.getElementById('password');
  var res = obj.value.length > 3;

  if (!res) {
    Swal.fire({
      icon: 'error',
      title: 'Invalid password',
      text: 'The password you enetered is invalid. Please try again. Minimum 4 characters...',
      confirmButtonText: 'Close',
      confirmButtonColor: '#669fe0'
    });
    return false;
  }
  window.location.href = 'start-page.html';
  return false;
}

function forgotPassword() {
  Swal.fire({
    title: 'Forgot Password?',
    text: 'Your password is the same password you use to sign in to your Microsoft Services. If uo forgot your password please contact your system administrator.',
    confirmButtonText: 'Close',
    confirmButtonColor: '#669fe0'
  });
}

// *************************************
// *********** CLOCK *******************
// *************************************

var clockEl = document.getElementById('clock');
if (clockEl) {
  runClock();
}
function runClock() {
 
  const hr = document.querySelector('.hr')
  const min = document.querySelector('.min')
  const sec = document.querySelector('.sec')

  const clockProgress = document.querySelector('.clock-progress')
  const circleProgressMin = document.querySelector('.circular-progress')
  
  const isTimer = clockProgress !== null;
  let progressStartSec = 0,
          progressStartMinute = 0,
          progressStartHour = 0;

  let clockProgressRotated = false;


  setInterval(() => {

      let day = new Date()
      let hour = day.getHours()
      let minutes = day.getMinutes()
      let seconds = day.getSeconds()

      let hrrotation = (30 * hour) + (0.5 * minutes);
      let minrotation = 6 * minutes;
      let secrotation = 6 * seconds;

      if(isTimer){
        progressStartSec++;

        if(progressStartSec == 60){
          progressStartMinute++;
          progressStartSec = 0;

          let minutes = progressStartMinute + progressStartHour * 60;
          circleProgressMin.style.background = `conic-gradient(#54b8ff ${(minutes / 1440) * 100 * 3.6}deg, #fff 0deg)`;

        }
        if(progressStartMinute == 60){
          progressStartHour++;
          progressStartMinute = 0;
        }
        if(!clockProgressRotated){
          clockProgress.style.transform = `rotate(${hrrotation}deg)`
          clockProgressRotated = true;
        }
        tick(progressStartSec, progressStartMinute, progressStartHour);
      }
      

      hr.style.transform =
          `translate(-50%,-100%) rotate(${hrrotation}deg)`
      min.style.transform =
          `translate(-50%,-100%) rotate(${minrotation}deg)`
      sec.style.transform =
          `translate(-50%,-85%) rotate(${secrotation}deg)`
    }, 1000);
}


function tick(one_second, one_minute, one_hour) {
  let timer = document.getElementById('js-timer')
  var parts = [];

  parts[0] = '' + one_hour;
  parts[1] = '' + one_minute
  parts[2] = '' + one_second;

  parts[0] = (parts[0].length == 1) ? '0' + parts[0] : parts[0];
  parts[1] = (parts[1].length == 1) ? '0' + parts[1] : parts[1];
  parts[2] = (parts[2].length == 1) ? '0' + parts[2] : parts[2];

  timer.innerText = parts.join(':');
}
// *************************************
// *********** CHART *******************
// *************************************
var chartEl = document.getElementById('chart');
if (chartEl) {
  chart();
}

function chart() {
  var labels = [
    'Czas Rozpoczęcia',
    'Event',
    'Calkowity czas pracy',
    'End'
  ];
  var colorHex = ['#198754', '#0d6efd', '#ffc107', '#dc3545'];
  const ctx = document.getElementById('chart').getContext('2d');
  const myChart = new Chart(ctx, {
    type: 'pie',
    data: {
      datasets: [{
        data: [55, 20, 10, 15],
        backgroundColor: colorHex
      }],
      labels: labels
    },
    options: {
      plugins: {
        legend: {
          display: false
        },
        datalabels: {
          color: 'red'
        }
      }
    }
  });
}

==> pEyOn___2022-12-16_05-13-00.zip: js/main.js <==
$(document).ready(function () {
  $('.js-btn').click(function(){
    if(!$(this).hasClass('active')){
      $(this).parents('ul').find('.js-btn').removeClass('active');
      $(this).addClass('active');
    }
  });
  
  $('.accordion-item a.btn-pause').click(function(){
    $(this).parents('.accordion-item').find('.form-check-input').removeClass('bg-success').addClass('bg-primary');
    $(this).find('i.mdi-pause-circle-outline').removeClass('mdi-pause-circle-outline text-secondary').addClass('mdi-pause-circle text-primary opacity-100');
  });
  
  $('.accordion-item .form-switch .form-check-input').change(function () {
    if (this.checked) {
      $(this).removeClass('bg-danger').addClass('bg-success');
      $(this).parents('.accordion-item').find('.btn-pause').removeClass('d-none');
      $(this).parents('.accordion-item').find('.last-use').addClass('d-none');
      $(this).parents('.accordion-item').find('.timer').removeClass('d-none');
    }else{
      $(this).removeClass('bg-success').addClass('bg-danger');
      $(this).parents('.accordion-item').find('.last-use').removeClass('d-none');
      $(this).parents('.accordion-item').find('.timer').addClass('d-none');
      $(this).parents('.accordion-item').find('.btn-pause').addClass('d-none');
      $(this).parents('.accordion-item').find('i').removeClass('mdi-pause-circle-outline mdi-pause-circle text-danger opacity-100').addClass('mdi-pause-circle-outline text-secondary');
    }
    if ($('.accordion-item .form-switch .form-check-input:checked').length > 1) {
      var myModal = new bootstrap.Modal(document.getElementById('conflictModal'));
      myModal.show();
    }
  });

});

// *************************************
// *********** POPUP *******************
// *************************************

function submitForm() {
  var obj = document.getElementById('password');
  var res = obj.value.length > 3;

  if (!res) {
    Swal.fire({
      icon: 'error',
      title: 'Invalid password',
      text: 'The password you enetered is invalid. Please try again. Minimum 4 characters...',
      confirmButtonText: 'Close',
      confirmButtonColor: '#669fe0'
    });
    return false;
  }
  window.location.href = 'start-page.html';
  return false;
}

function forgotPassword() {
  Swal.fire({
    title: 'Forgot Password?',
    text: 'Your password is the same password you use to sign in to your Microsoft Services. If uo forgot your password please contact your system administrator.',
    confirmButtonText: 'Close',
    confirmButtonColor: '#669fe0'
  });
}

// *************************************
// *********** CLOCK *******************
// *************************************

var clockEl = document.getElementById('clock');
if (clockEl) {
  runClock();
}

const startDate = new Date()

function runClock() {
 
  const hr = document.querySelector('.hr')
  const min = document.querySelector('.min')
  const sec = document.querySelector('.sec')

  const clockProgress = document.querySelector('.clock-progress')
  const circleProgressMin = document.querySelector('.circular-progress')
  
  const isTimer = clockProgress !== null;


  let clockProgressRotated = false;


  setInterval(() => {

      let day = new Date()
      let dayHour = day.getHours()
      let dayMinutes = day.getMinutes()
      let daySeconds = day.getSeconds()

      let hrrotation = (30 * dayHour) + (0.5 * dayMinutes);
      let minrotation = 6 * dayMinutes;
      let secrotation = 6 * daySeconds;

      let seconds = Math.floor((day - startDate) / 1000);
      let minutes = Math.floor(seconds / 60);
      let hours = Math.floor(minutes / 60);

      if(isTimer){
   
        circleProgressMin.style.background = `conic-gradient(#54b8ff ${minutes * 0.5}deg, #fff 0deg)`; 

        if(!clockProgressRotated){
          clockProgress.style.transform = `rotate(${hrrotation}deg)`
          clockProgressRotated = true;
        }
        tick(seconds % 60, minutes % 60, hours % 24);
      }

      hr.style.transform =
          `translate(-50%,-100%) rotate(${hrrotation}deg)`
      min.style.transform =
          `translate(-50%,-100%) rotate(${minrotation}deg)`
      sec.style.transform =
          `translate(-50%,-85%) rotate(${secrotation}deg)`
    }, 1000);
}


function tick(one_second, one_minute, one_hour) {
  let timer = document.getElementById('js-timer')
  var parts = [];

  parts[0] = '' + one_hour;
  parts[1] = '' + one_minute
  parts[2] = '' + one_second;

  parts[0] = (parts[0].length == 1) ? '0' + parts[0] : parts[0];
  parts[1] = (parts[1].length == 1) ? '0' + parts[1] : parts[1];
  parts[2] = (parts[2].length == 1) ? '0' + parts[2] : parts[2];

  timer.innerText = parts.join(':');
}
// *************************************
// *********** CHART *******************
// *************************************
var chartEl = document.getElementById('chart');
if (chartEl) {
  chart();
}

function chart() {
  var labels = [
    'Czas Rozpoczęcia',
    'Event',
    'Calkowity czas pracy',
    'End'
  ];
  var colorHex = ['#198754', '#0d6efd', '#ffc107', '#dc3545'];
  const ctx = document.getElementById('chart').getContext('2d');
  const myChart = new Chart(ctx, {
    type: 'pie',
    data: {
      datasets: [{
        data: [55, 20, 10, 15],
        backgroundColor: colorHex
      }],
      labels: labels
    },
    options: {
      plugins: {
        legend: {
          display: false
        },
        datalabels: {
          color: 'red'
        }
      }
    }
  });
}
